@@ -2,7 +2,6 @@
 #
 # This file is part of InforION.
 #
-
 #
 # InforION is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,11 +10,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
-
-
 import pkg_resources
 
-PROGRAM_NAME = 'inforion'
+PROGRAM_NAME = "inforion"
 
 # Official PEP 396
-__version__ = pkg_resources.get_distribution('inforion').version
\ No newline at end of file
+__version__ = pkg_resources.get_distribution("inforion").version
